==> openshift-model-operatorhub-5.10.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/ResourceListFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ResourceListFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent<A>{
  public ResourceListFluentImpl() {
  }
  public ResourceListFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceList instance) {
    this.withGroup(instance.getGroup()); 
    this.withInstances(instance.getInstances()); 
    this.withKind(instance.getKind()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String group;
  private java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder> instances =  new java.util.ArrayList<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder>();
  private java.lang.String kind;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getGroup() {
    return this.group;
  }
  public A withGroup(java.lang.String group) {
    this.group=group; return (A) this;
  }
  public java.lang.Boolean hasGroup() {
    return this.group != null;
  }
  
  /**
   * Method is deprecated. use withGroup instead.
   */
  @java.lang.Deprecated
  public A withNewGroup(java.lang.String arg0) {
    return (A)withGroup(new String(arg0));
  }
  public A addToInstances(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item) {
    if (this.instances == null) {this.instances = new java.util.ArrayList<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder>();}
    io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder(item);_visitables.get("instances").add(index >= 0 ? index : _visitables.get("instances").size(), builder);this.instances.add(index >= 0 ? index : instances.size(), builder); return (A)this;
  }
  public A setToInstances(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item) {
    if (this.instances == null) {this.instances = new java.util.ArrayList<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder>();}
    io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder(item);
    if (index < 0 || index >= _visitables.get("instances").size()) { _visitables.get("instances").add(builder); } else { _visitables.get("instances").set(index, builder);}
    if (index < 0 || index >= instances.size()) { instances.add(builder); } else { instances.set(index, builder);}
     return (A)this;
  }
  public A addToInstances(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance... items) {
    if (this.instances == null) {this.instances = new java.util.ArrayList<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder>();}
    for (io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item : items) {io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder(item);_visitables.get("instances").add(builder);this.instances.add(builder);} return (A)this;
  }
  public A addAllToInstances(java.util.Collection<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance> items) {
    if (this.instances == null) {this.instances = new java.util.ArrayList<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder>();}
    for (io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item : items) {io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder(item);_visitables.get("instances").add(builder);this.instances.add(builder);} return (A)this;
  }
  public A removeFromInstances(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance... items) {
    for (io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item : items) {io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder(item);_visitables.get("instances").remove(builder);if (this.instances != null) {this.instances.remove(builder);}} return (A)this;
  }
  public A removeAllFromInstances(java.util.Collection<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance> items) {
    for (io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item : items) {io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder(item);_visitables.get("instances").remove(builder);if (this.instances != null) {this.instances.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromInstances(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder> predicate) {
    if (instances == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder> each = instances.iterator();
    final List visitables = _visitables.get("instances");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildInstances instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance> getInstances() {
    return build(instances);
  }
  public java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance> buildInstances() {
    return build(instances);
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance buildInstance(java.lang.Integer index) {
    return this.instances.get(index).build();
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance buildFirstInstance() {
    return this.instances.get(0).build();
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance buildLastInstance() {
    return this.instances.get(instances.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance buildMatchingInstance(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder> predicate) {
    for (io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder item: instances) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingInstance(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder> predicate) {
    for (io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder item: instances) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withInstances(java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance> instances) {
    if (this.instances != null) { _visitables.get("instances").removeAll(this.instances);}
    if (instances != null) {this.instances = new java.util.ArrayList<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder>(); for (io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item : instances){this.addToInstances(item);}} else { this.instances = null;} return (A) this;
  }
  public A withInstances(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance... instances) {
    if (this.instances != null) {this.instances.clear();}
    if (instances != null) {for (io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item :instances){ this.addToInstances(item);}} return (A) this;
  }
  public java.lang.Boolean hasInstances() {
    return instances != null && !instances.isEmpty();
  }
  public A addNewInstance(java.lang.String name,java.lang.String namespace) {
    return (A)addToInstances(new ResourceInstance(name, namespace));
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent.InstancesNested<A> addNewInstance() {
    return new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluentImpl.InstancesNestedImpl();
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent.InstancesNested<A> addNewInstanceLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item) {
    return new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluentImpl.InstancesNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent.InstancesNested<A> setNewInstanceLike(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item) {
    return new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluentImpl.InstancesNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent.InstancesNested<A> editInstance(java.lang.Integer index) {
    if (instances.size() <= index) throw new RuntimeException("Can't edit instances. Index exceeds size.");
    return setNewInstanceLike(index, buildInstance(index));
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent.InstancesNested<A> editFirstInstance() {
    if (instances.size() == 0) throw new RuntimeException("Can't edit first instances. The list is empty.");
    return setNewInstanceLike(0, buildInstance(0));
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent.InstancesNested<A> editLastInstance() {
    int index = instances.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last instances. The list is empty.");
    return setNewInstanceLike(index, buildInstance(index));
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent.InstancesNested<A> editMatchingInstance(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder> predicate) {
    int index = -1;
    for (int i=0;i<instances.size();i++) { 
    if (predicate.test(instances.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching instances. No match found.");
    return setNewInstanceLike(index, buildInstance(index));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ResourceListFluentImpl that = (ResourceListFluentImpl) o;
    if (group != null ? !group.equals(that.group) :that.group != null) return false;
    if (instances != null ? !instances.equals(that.instances) :that.instances != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(group,  instances,  kind,  additionalProperties,  super.hashCode());
  }
  public class InstancesNestedImpl<N> extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent.InstancesNested<N>> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent.InstancesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    InstancesNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder(this, item);
    }
    InstancesNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder(this);
    }
    io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) ResourceListFluentImpl.this.setToInstances(index,builder.build());
    }
    public N endInstance() {
      return and();
    }
    
  }
  
}

==> openshift-model-operatorhub-5.12.3-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/ResourceListFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ResourceListFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent<A>{
  public ResourceListFluentImpl() {
  }
  public ResourceListFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceList instance) {
    this.withGroup(instance.getGroup()); 
    this.withInstances(instance.getInstances()); 
    this.withKind(instance.getKind()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String group;
  private java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder> instances =  new java.util.ArrayList<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder>();
  private java.lang.String kind;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getGroup() {
    return this.group;
  }
  public A withGroup(java.lang.String group) {
    this.group=group; return (A) this;
  }
  public java.lang.Boolean hasGroup() {
    return this.group != null;
  }
  
  /**
   * Method is deprecated. use withGroup instead.
   */
  @java.lang.Deprecated
  public A withNewGroup(java.lang.String arg0) {
    return (A)withGroup(new String(arg0));
  }
  public A addToInstances(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item) {
    if (this.instances == null) {this.instances = new java.util.ArrayList<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder>();}
    io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder(item);_visitables.get("instances").add(index >= 0 ? index : _visitables.get("instances").size(), builder);this.instances.add(index >= 0 ? index : instances.size(), builder); return (A)this;
  }
  public A setToInstances(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item) {
    if (this.instances == null) {this.instances = new java.util.ArrayList<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder>();}
    io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder(item);
    if (index < 0 || index >= _visitables.get("instances").size()) { _visitables.get("instances").add(builder); } else { _visitables.get("instances").set(index, builder);}
    if (index < 0 || index >= instances.size()) { instances.add(builder); } else { instances.set(index, builder);}
     return (A)this;
  }
  public A addToInstances(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance... items) {
    if (this.instances == null) {this.instances = new java.util.ArrayList<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder>();}
    for (io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item : items) {io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder(item);_visitables.get("instances").add(builder);this.instances.add(builder);} return (A)this;
  }
  public A addAllToInstances(java.util.Collection<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance> items) {
    if (this.instances == null) {this.instances = new java.util.ArrayList<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder>();}
    for (io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item : items) {io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder(item);_visitables.get("instances").add(builder);this.instances.add(builder);} return (A)this;
  }
  public A removeFromInstances(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance... items) {
    for (io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item : items) {io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder(item);_visitables.get("instances").remove(builder);if (this.instances != null) {this.instances.remove(builder);}} return (A)this;
  }
  public A removeAllFromInstances(java.util.Collection<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance> items) {
    for (io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item : items) {io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder(item);_visitables.get("instances").remove(builder);if (this.instances != null) {this.instances.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromInstances(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder> predicate) {
    if (instances == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder> each = instances.iterator();
    final List visitables = _visitables.get("instances");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildInstances instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance> getInstances() {
    return build(instances);
  }
  public java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance> buildInstances() {
    return build(instances);
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance buildInstance(java.lang.Integer index) {
    return this.instances.get(index).build();
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance buildFirstInstance() {
    return this.instances.get(0).build();
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance buildLastInstance() {
    return this.instances.get(instances.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance buildMatchingInstance(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder> predicate) {
    for (io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder item: instances) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingInstance(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder> predicate) {
    for (io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder item: instances) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withInstances(java.util.List<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance> instances) {
    if (this.instances != null) { _visitables.get("instances").removeAll(this.instances);}
    if (instances != null) {this.instances = new java.util.ArrayList(); for (io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item : instances){this.addToInstances(item);}} else { this.instances = null;} return (A) this;
  }
  public A withInstances(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance... instances) {
    if (this.instances != null) {this.instances.clear();}
    if (instances != null) {for (io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item :instances){ this.addToInstances(item);}} return (A) this;
  }
  public java.lang.Boolean hasInstances() {
    return instances != null && !instances.isEmpty();
  }
  public A addNewInstance(java.lang.String name,java.lang.String namespace) {
    return (A)addToInstances(new ResourceInstance(name, namespace));
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent.InstancesNested<A> addNewInstance() {
    return new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluentImpl.InstancesNestedImpl();
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent.InstancesNested<A> addNewInstanceLike(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item) {
    return new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluentImpl.InstancesNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent.InstancesNested<A> setNewInstanceLike(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item) {
    return new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluentImpl.InstancesNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent.InstancesNested<A> editInstance(java.lang.Integer index) {
    if (instances.size() <= index) throw new RuntimeException("Can't edit instances. Index exceeds size.");
    return setNewInstanceLike(index, buildInstance(index));
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent.InstancesNested<A> editFirstInstance() {
    if (instances.size() == 0) throw new RuntimeException("Can't edit first instances. The list is empty.");
    return setNewInstanceLike(0, buildInstance(0));
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent.InstancesNested<A> editLastInstance() {
    int index = instances.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last instances. The list is empty.");
    return setNewInstanceLike(index, buildInstance(index));
  }
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent.InstancesNested<A> editMatchingInstance(java.util.function.Predicate<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder> predicate) {
    int index = -1;
    for (int i=0;i<instances.size();i++) { 
    if (predicate.test(instances.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching instances. No match found.");
    return setNewInstanceLike(index, buildInstance(index));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ResourceListFluentImpl that = (ResourceListFluentImpl) o;
    if (group != null ? !group.equals(that.group) :that.group != null) return false;
    if (instances != null ? !instances.equals(that.instances) :that.instances != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(group,  instances,  kind,  additionalProperties,  super.hashCode());
  }
  public class InstancesNestedImpl<N> extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent.InstancesNested<N>> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceListFluent.InstancesNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    InstancesNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstance item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder(this, item);
    }
    InstancesNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder(this);
    }
    io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceInstanceBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) ResourceListFluentImpl.this.setToInstances(index,builder.build());
    }
    public N endInstance() {
      return and();
    }
    
  }
  
}
